@@ -1,14 +1,12 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
 from trytond.model import fields
-from trytond import backend
 from trytond.pool import PoolMeta
 
 __all__ = ['User']
 
 
-class User:
-    __metaclass__ = PoolMeta
+class User(metaclass=PoolMeta):
     __name__ = "res.user"
     dashboard_layout = fields.Selection([
         ('square', 'Square'),
@@ -28,17 +26,6 @@ class User:
             'dashboard_actions',
             ]
 
-    @classmethod
-    def __register__(cls, module_name):
-        TableHandler = backend.get('TableHandler')
-
-        super(User, cls).__register__(module_name)
-
-        table = TableHandler(cls, module_name)
-
-        # Migration from 1.6
-        table.not_null_action('dashboard_layout', action='remove')
-
     @staticmethod
     def default_dashboard_layout():
         return 'square'
